#!/bin/bash
# Authors: 	Dalibor Pospíšil	<dapospis@redhat.com>
#   Author: Dalibor Pospisil <dapospis@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2013 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   library-prefix = dpcommon
#   library-version = 3
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
: <<'=cut'
=pod

=head1 NAME

BeakerLib library dpcommon

=head1 DESCRIPTION

This is a meta-library containing just dependencies.

=head1 USAGE

To use this functionality you need to import library distribution/dpcommon and add
following line to Makefile.

	@echo "RhtsRequires:    library(distribution/dpcommon)" >> $(METADATA)

=cut


rlFetchRpmForInstalled(){
  local PKGNAME=$1 RPM
  if ! RPM=$(rpm -q ${PKGNAME})
  then
    rlLogError "The package is not installed, can't download the RPM"
    return 1
  fi
  rlLog "Fetching rpm for installed $PKGNAME"

  rlLogInfo "Installed $PKGNAME version: $RPM"
  rlRpmDownload `rpm -q --qf '%{name} %{version} %{release} %{arch}' $PKGNAME`
}


KernelWhichBootloader() {
  local CONF_NAME BASE
  BLOADER_CONF_FILE=''
  BLOADER=''
  tcfChk "Determine bootloader" && {
    case `rlGetArch` in
      i386|x86_64)
        if rlIsRHEL '<7'; then
          CONF_NAME="grub.conf"
          BLOADER="GRUB"
        else
          CONF_NAME="grub.cfg"
          BLOADER="GRUB2"
        fi
      ;;
      ia64)
        CONF_NAME="elilo.conf)"
        BLOADER="ELILO"
      ;;
      ppc|ppc64)
        if rlIsRHEL '<7'; then
          CONF_NAME="yaboot.conf"
          BLOADER="YABOOT"
        else
          CONF_NAME="grub.cfg"
          BLOADER="GRUB2"
        fi
      ;;
      s390|s390x)
        CONF_NAME="zipl.conf"
        BLOADER="ZIPL"
      ;;
      *) rlLogFatal "No suitable arch found!" ; rlNOK
      ;;
    esac
    LogDebug -f "current architecture in `rlGetArch`"
    LogDebug -f "CONF_NAME='$CONF_NAME'"
    LogDebug -f "BLOADER='$BLOADER'"
    tcfTry &&{
      for BASE in /etc /boot; do
        [ ! -f "$BLOADER_CONF_FILE" ] && BLOADER_CONF_FILE=$(find $BASE -name $CONF_NAME)
      done
      BLOADER_CONF_FILE=$(readlink -f $BLOADER_CONF_FILE)
      [ -f "$BLOADER_CONF_FILE" ]; tcfE2R
      if tcfRES; then
        LogDebug -f "Bootloader configuration file: $BLOADER_CONF_FILE"
      else
        rlLogFatal "No bootloader found!"
      fi
      LogDebug -f "tcfRES='`tcfRES -p`'"
      tcfRES
    tcfFin;}
  tcfFin --no-assert;}
}


KernelAppendBootOpt() {
  [ -z "$BLOADER" ] && KernelWhichBootloader
  [ -z "$BLOADER_CONF_FILE" ] && KernelWhichBootloader
  tcfChk "Append boot parameters" && {
    case "$BLOADER" in
      GRUB)
        ReplaceInFile -e -a '^[[:space:]]\+kernel' "$" " $1"  $BLOADER_CONF_FILE
      ;;
      GRUB2)
        rlReplaceInFile -e -a '^[[:space:]]\+linux' "$" " $1"  $BLOADER_CONF_FILE
      ;;
      ELILO|YABOOT)
        ReplaceInFile -e -a '^[[:space:]]\+append' '"$' " ${1}\"" $BLOADER_CONF_FILE
      ;;
      ZIPL)
        ReplaceInFile -e -a '^[[:space:]]\+parameters' '"$' " ${1}\"" $BLOADER_CONF_FILE
        /sbin/zipl; tcfE2R; LogDebug -f "/sbin/zipl returned -> $?"
      ;;
    esac
  tcfFin --no-assert;}
}


ReplaceInFile() {
  local addr="" multi=0 sed_opts="" addr2=''
  while [ -n "$1" ]; do
    case $1 in
    --)
      shift
      break
      ;;
    -a|--addr|--address)
      addr="/$2/ "
      addr2="$2"
      shift
      ;;
    -m|--multi|--multi-line)
      multi=1
      ;;
    -*)
      sed_opts="$sed_opts $1"
      ;;
    *)
      break
      ;;
    esac
    shift
  done
  if [ $multi -eq 0 ]; then
    local opts=$(cat $3 | grep -e "$1")
    [ -n "$addr" ] && opts=$(echo "$opts" | grep -e "$addr2")
    LogDebug -f "previous kernel params $opts"
    sed -i ${sed_opts} "${addr}s/$1/$2/g" $3
    local opts=$(cat $3 | grep -e "$1")
    [ -n "$addr" ] && opts=$(echo "$opts" | grep -e "$addr2")
    LogDebug -f "new kernel params $opts"
  else
    true
  fi
}

value_difference_percentage() {
  local a="scale=10; h=($1); l=($2); if ( h < l ) { a=h; h=l; l=a; }; d=h-l; if (h<0) h=-h; if (l<0) l=-l; if ( h < l ) { a=h; h=l; l=a; }; if ( l != 0 ) d/l*100 else 1000000000000000000000000000"
  rlLogDebug "value diff: $a"
  echo $a | bc | sed -e 's/^\./0\0/'
}

compare_with_tolerance() {
  rlLog "check that $1 and $2 does not differ more than $3%"
  local v=$(value_difference_percentage $1 $2 |cut -d . -f 1)
  rlLog "values differ by $v%"
  [ $v -le $3 ]
}

# dpcommonLibraryLoaded ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ {{{
dpcommonLibraryLoaded() {
  return 0
}; # end of dpcommonLibraryLoaded }}}


: <<'=cut'
=pod

=head1 AUTHORS

=over

=item *

Dalibor Pospisil <dapospis@redhat.com>

=back

=cut

